%global major       1
%define libname     %mklibname ispcrt %major
%define libname_cpu %mklibname ispcrt-device-cpu %major
%define devname     %mklibname ispcrt -d

%global with_snapshot	0
%global date		20190309
%global commit		34da2d23bbf32abf44da11d2cdca595dc7318cec
%global shortcommit	%(c=%{commit}; echo ${c:0:7})

%bcond_with examples

%global toolchain clang

%define rel	1

Name:		ispc
Version:	1.26.0
%if %{with_snapshot}
Release:	%mkrel -c git%{date} %{rel}
%else
Release:	%mkrel %{rel}
%endif
Summary:	C-based SPMD programming language compiler
Group:		Development/C
License:	BSD
URL:		https://ispc.github.io/
%if %{with_snapshot}
Source0:	https://github.com/%{name}/%{name}/archive/%{commit}/%{name}-%{shortcommit}.tar.gz
%else
Source0:	https://github.com/%{name}/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz
%endif
Patch1:		0001-Fix-getWithCaptureInfo-for-LLVM-20.1.patch
BuildRequires:	bison
BuildRequires:	cmake
BuildRequires:	clang-devel
BuildRequires:	doxygen
BuildRequires:	flex
BuildRequires:	git
BuildRequires:	gcc-c++
BuildRequires:	llvm-devel >= 16.0.0
BuildRequires:	rst2html
BuildRequires:	pkgconfig(libffi)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(tbb)
BuildRequires:	pkgconfig(zlib)

# Upstream only supports these architectures
ExclusiveArch:	x86_64 %{arm64}

# patches from upstream (starting from 100)

%if ! %{with examples}
Obsoletes:	%{name}-examples < %{version}-%{release}
%endif

%description
A compiler for a variant of the C programming language, with extensions for
"single program, multiple data" (SPMD) programming.

%package examples
Summary:	Examples binaries for ispc
Group:		Development/C

%description examples
This package contains the examples binaries for the ispc SPMD compiler.

%package -n %libname
Summary:	Library for ispc
Group:		System/Libraries

%description -n %libname
Library for ispc.

%package -n %libname_cpu
Summary:	Library for ispc
Group:		System/Libraries

%description -n %libname_cpu
Library for ispc.

%package -n %devname
Group:		Development/C
Summary:	Development files for %{name}
Requires:	%{libname}%{?_isa} = %{version}-%{release}
Requires:	%{libname_cpu}%{?_isa} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %devname
The %{name}-devel package contains libraries and header files for
applications that use %{name}.

%prep
%if %{with_snapshot}
%autosetup -n %{name}-%{commit} -p1
%else
%autosetup -n %{name}-%{version} -p1
%endif

# Suppress warning message as error
sed -i 's| -Werror ||g' CMakeLists.txt

# Fix BUILD_VERSION
sed -i -e '/BUILD_VERSION/s/${GIT_COMMIT_HASH}/%{version}/' CMakeLists.txt

# Fix all Python shebangs recursively in .
%py3_shebang_fix .

%build
%cmake	\
	-DISPC_INCLUDE_EXAMPLES=%{?with_examples:ON}%{!?with_examples:OFF} \
	-DISPC_INCLUDE_TESTS=OFF
%cmake_build

(
 cd ./docs/
 ./build.sh
)

%install
%cmake_install

#Remove static file
rm %{buildroot}%{_libdir}/lib%{name}rt_static.a

%files
%license LICENSE.txt
%doc docs/*.html docs/ReleaseNotes.txt
%{_bindir}/%{name}
%{_bindir}/check_isa

%if %{with examples}
%files examples
%{_prefix}/lib/ispc/examples
%endif

%files -n %libname
%{_libdir}/lib%{name}rt.so.%{major}{,.*}

%files -n %libname_cpu
%{_libdir}/libispcrt_device_cpu.so.%{major}{,.*}

%files -n %devname
%{_includedir}/%{name}rt/
%{_libdir}/cmake/%{name}rt-%{version}/
%{_libdir}/lib%{name}rt.so
%{_libdir}/lib%{name}rt_device_cpu.so


%changelog
* Thu May 01 2025 wally <wally> 1.26.0-1.mga10
+ Revision: 2180259
- new version 1.26.0
- rebuild for llvm 20.1.3

* Tue Nov 19 2024 daviddavid <daviddavid> 1.25.3-3.mga10
+ Revision: 2117699
- rebuild for missing pkgs

* Mon Nov 18 2024 wally <wally> 1.25.3-2.mga10
+ Revision: 2117579
- build using clang toolchain
- rebuild for LLVM 19.1.3

* Tue Nov 12 2024 ghibo <ghibo> 1.25.3-1.mga10
+ Revision: 2114670
- Update to version 1.25.3

* Sat Oct 19 2024 ghibo <ghibo> 1.25.1-1.mga10
+ Revision: 2108146
- Update to version 1.25.1

* Sat Oct 19 2024 ghibo <ghibo> 1.25.0-1.mga10
+ Revision: 2108144
- Update to version 1.25.0

* Sun Sep 15 2024 daviddavid <daviddavid> 1.24.0-1.mga10
+ Revision: 2096755
- new version: 1.24.0

* Sun Mar 31 2024 daviddavid <daviddavid> 1.23.0-2.mga10
+ Revision: 2053389
- rebuild for new llvm/clang 17

* Tue Feb 20 2024 daviddavid <daviddavid> 1.23.0-1.mga10
+ Revision: 2042610
- new version: 1.23.0
- remove merged upstream patches

* Fri Nov 11 2022 ghibo <ghibo> 1.18.1-1.mga9
+ Revision: 1905523
- Update to release 1.18.1.
- Backport more patches from upstream 1.19.0-dev to fix crashes during oidn package building.
- Reorder patchsets.

* Sun Sep 25 2022 tv <tv> 1.18.0-2.mga9
+ Revision: 1892275
- Add support for llvm-15
- Rebuild for llvm-15

* Sun May 08 2022 tv <tv> 1.18.0-1.mga9
+ Revision: 1856758
- Update to 1.18.0

* Sat Apr 02 2022 tv <tv> 1.17.0-2.mga9
+ Revision: 1840359
- Rebuild for llvm-14

* Sun Mar 13 2022 ghibo <ghibo> 1.17.0-1.mga9
+ Revision: 1790827
- Update to release 1.17.0
- Drop Patch1 (merged upstream)

* Sat Dec 25 2021 wally <wally> 1.16.1-2.mga9
+ Revision: 1763620
- drop empty examples pkg

* Sat Dec 25 2021 wally <wally> 1.16.1-1.mga9
+ Revision: 1763615
- disable examples build
- enable aarch64 build
- add patch to fix build with llvm 13
- use proper linker flags
+ tv <tv>
- 1.16.1
- Rebuild for llvm 13.0

* Mon Jun 14 2021 tv <tv> 1.16.0-1.mga9
+ Revision: 1730741
- "Fix" file list
- Update to 1.16.0

* Wed May 19 2021 tv <tv> 1.15.0-1.mga9
+ Revision: 1725561
- Update to 1.15.0
- rebuild for llvm/clang-12

* Thu Nov 26 2020 tv <tv> 1.14.1-2.mga8
+ Revision: 1649613
- rebuild for llvm/clang 11.0

* Sun Sep 13 2020 ghibo <ghibo> 1.14.1-1.mga8
+ Revision: 1625446
- Disable aarch64 building.
- Re-enable arm components.
- Disable ARM components
- Update to release 1.14.1.
- Drop patches merged upstream.
- Fix cmake_build arguments
- Update to release 1.14.0
+ tv <tv>
- kill old patches
- try to fix build

* Mon Jun 01 2020 ghibo <ghibo> 1.13.0-3.mga8
+ Revision: 1589347
- Cleaned SPEC file

* Mon Jun 01 2020 ghibo <ghibo> 1.13.0-2.mga8
+ Revision: 1589329
- Bump rel
- Exclusive arch x86_64 only
- Temporary disable i586 arch
- Fix clang-cpp patch
- Add patches from git to fix i586 building
- Switch from autosetup to setup for finetuning the patchset
- Rework clang-cpp patch.
- Add a BR
- Update to release 1.13.0
- Added two patch to override compiling errors
+ tv <tv>
- rebuild with llvm 10
+ wally <wally>
- build with new cmake macros

* Tue Sep 17 2019 tv <tv> 1.12.0-1.mga8
+ Revision: 1443128
- Update to 1.12.0
- Switch dependency to Python 3
- rebuild for llvm-9.0

* Sun May 26 2019 ghibo <ghibo> 1.11.0-3.mga7
+ Revision: 1399198
- Exclude arm building for now

* Sun May 26 2019 ghibo <ghibo> 1.11.0-2.mga7
+ Revision: 1399186
- Add patches from git for arm building.

* Sun May 26 2019 ghibo <ghibo> 1.11.0-1.mga7
+ Revision: 1399138
- imported package ispc


* Sat May 25 2019 ghibo <ghibo> - 1.11.0-1.mga7
- Initial release based on FC.
- Add docs
